==> charcoal-0.2.0-alpha.zip: charcoal-0.2.0-alpha/charcoal/charcoal.inc.php <==
<?php

//==================================================================
// OSɂăpX؂蕶𔻒

if (!defined('PATH_SEPARATOR')) {
	if (strtoupper(substr(PHP_OS, 0, 3)) === 'WIN') {
		define('PATH_SEPARATOR', ';');
	} else {
		define('PATH_SEPARATOR', ':');
	}
}

//==================================================================
// CN[hpXݒ

ini_set(
		'include_path', 
//		'.' 
		PATH_SEPARATOR . CHARCOAL_HOME
		. PATH_SEPARATOR . EXTLIB_DIR
		. PATH_SEPARATOR . WEBAPP_DIR . "/" . APPLICATION . "/classes/"
	);

//==================================================================
// autoload

function __autoload( $class_name )
{
	require_once ( 'core/ClassLoader.class.php' );

	$loaded = charcoal_ClassLoader::loadClass( $class_name );
}

//==================================================================
// Oo͊֐

// TRACEo
function log_trace( $logger_names, $message, $file, $line )
{
	charcoal_Logger::writeln( "T:$logger_names", $message, $file, $line );
}

// INFOo
function log_info( $logger_names, $message, $file, $line )
{
	charcoal_Logger::writeln( "I:$logger_names", $message, $file, $line );
}

// WARNINGo
function log_warning( $logger_names, $message, $file, $line )
{
	charcoal_Logger::writeln( "W:$logger_names", $message, $file, $line );
}

// DEBUGo
function log_debug( $logger_names, $message, $file, $line )
{
	charcoal_Logger::writeln( "D:$logger_names", $message, $file, $line );
}

// ERRORo
function log_error( $logger_names, $message, $file, $line )
{
	charcoal_Logger::writeln( "E:$logger_names", $message, $file, $line );
}

// FATALo
function log_fatal( $logger_names, $message, $file, $line )
{
	charcoal_Logger::writeln( "F:$logger_names", $message, $file, $line );
}

//==================================================================
// z_v

function array_dump( $array )
{
	print charcoal_System::arrayToString($array);
}

//==================================================================
// vt@Cǂݍ

$host = gethostbyaddr($_SERVER["SERVER_ADDR"]);
//$host = $_SERVER["SERVER_NAME"];

charcoal_Profile::load( $host );

//==================================================================
// ZbV̊JniÂZbV͍폜AVID𔭍sj

if ( charcoal_Profile::getBoolean('USE_SESSION') ){
	session_cache_limiter('private, must-revalidate');
	session_name( APPLICATION );
	session_start();
	//session_regenerate_id( TRUE );
	//session_cache_limiter('private, must-revalidate');
}

==> charcoal-0.3.0-alpha.zip: charcoal-0.3.0-alpha/charcoal/charcoal.inc.php <==
<?php

//==================================================================
// OSɂăpX؂蕶𔻒

if (!defined('PATH_SEPARATOR')) {
	if (strtoupper(substr(PHP_OS, 0, 3)) === 'WIN') {
		define('PATH_SEPARATOR', ';');
	} else {
		define('PATH_SEPARATOR', ':');
	}
}

//==================================================================
// 萔

define( 'PROC_KEYWORD', 'proc' );

//==================================================================
// CN[hpXݒ

ini_set(
		'include_path', 
//		'.' 
		PATH_SEPARATOR . CHARCOAL_HOME
		. PATH_SEPARATOR . EXTLIB_DIR
		. PATH_SEPARATOR . WEBAPP_DIR . "/" . APPLICATION . "/classes/"
	);

//==================================================================
// autoload

function __autoload( $class_name )
{
	require_once ( 'core/ClassLoader.class.php' );

	$loaded = charcoal_ClassLoader::loadClass( $class_name );
}

//==================================================================
// Oo͊֐

// TRACEo
function log_trace( $logger_names, $message, $file, $line )
{
	charcoal_Logger::writeln( "T:$logger_names", $message, $file, $line );
}

// INFOo
function log_info( $logger_names, $message, $file, $line )
{
	charcoal_Logger::writeln( "I:$logger_names", $message, $file, $line );
}

// WARNINGo
function log_warning( $logger_names, $message, $file, $line )
{
	charcoal_Logger::writeln( "W:$logger_names", $message, $file, $line );
}

// DEBUGo
function log_debug( $logger_names, $message, $file, $line )
{
	charcoal_Logger::writeln( "D:$logger_names", $message, $file, $line );
}

// ERRORo
function log_error( $logger_names, $message, $file, $line )
{
	charcoal_Logger::writeln( "E:$logger_names", $message, $file, $line );
}

// FATALo
function log_fatal( $logger_names, $message, $file, $line )
{
	charcoal_Logger::writeln( "F:$logger_names", $message, $file, $line );
}

//==================================================================
// z_v

function array_dump( $array, $title = NULL )
{
	print charcoal_System::arrayToString($array,$title);
}

//==================================================================
// vt@Cǂݍ

$host = gethostbyaddr($_SERVER["SERVER_ADDR"]);
//$host = $_SERVER["SERVER_NAME"];

charcoal_Profile::load( $host );

//==================================================================
// v~eBu֐

function s( $data, $encoding = NULL )
{
	return new charcoal_String( $data, $encoding );
}
